@@ -6,9 +6,7 @@ from .connected_es import create_connected_es
 from .emission_objective import create_emission_objective
 from .expansion_plan_example import create_expansion_plan_example
 from .fpwe import create_fpwe
-from .mssesu import create_mssesu
 from .mwe import create_mwe
-from .self_similar_energy_system import create_self_similar_energy_system
 from .simple_transformer_grid_es import create_simple_transformer_grid_es
 from .storage_example import create_storage_example
 from .storage_fixed_ratio_expansion_example import (
@@ -17,5 +15,4 @@ from .storage_fixed_ratio_expansion_example import (
 from .time_varying_efficiency_transformer import (
     create_time_varying_efficiency_transformer,
 )
-from .variable_chp import create_variable_chp
 from .zero_costs_es import create_zero_costs_es
